==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/regions/ta.php <==
<?php

return [
    'Names' => [
        'AD' => 'அன்டோரா',
        'AE' => 'ஐக்கிய அரபு எமிரேட்ஸ்',
        'AF' => 'ஆஃப்கானிஸ்தான்',
        'AG' => 'ஆண்டிகுவா மற்றும் பார்புடா',
        'AI' => 'அங்கியுலா',
        'AL' => 'அல்பேனியா',
        'AM' => 'அர்மேனியா',
        'AO' => 'அங்கோலா',
        'AQ' => 'அண்டார்டிகா',
        'AR' => 'அர்ஜென்டினா',
        'AS' => 'அமெரிக்க சமோவா',
        'AT' => 'ஆஸ்திரியா',
        'AU' => 'ஆஸ்திரேலியா',
        'AW' => 'அரூபா',
        'AX' => 'ஆலந்து தீவுகள்',
        'AZ' => 'அசர்பைஜான்',
        'BA' => 'போஸ்னியா & ஹெர்ஸகோவினா',
        'BB' => 'பார்படாஸ்',
        'BD' => 'பங்களாதேஷ்',
        'BE' => 'பெல்ஜியம்',
        'BF' => 'புர்கினா ஃபாஸோ',
        'BG' => 'பல்கேரியா',
        'BH' => 'பஹ்ரைன்',
        'BI' => 'புருண்டி',
        'BJ' => 'பெனின்',
        'BL' => 'செயின்ட் பார்தேலெமி',
        'BM' => 'பெர்முடா',
        'BN' => 'புருனே',
        'BO' => 'பொலிவியா',
        'BQ' => 'கரீபியன் நெதர்லாந்து',
        'BR' => 'பிரேசில்',
        'BS' => 'பஹாமாஸ்',
        'BT' => 'பூடான்',
        'BV' => 'பொவேட் தீவு',
        'BW' => 'போட்ஸ்வானா',
        'BY' => 'பெலாரஸ்',
        'BZ' => 'பெலிஸ்',
        'CA' => 'கனடா',
        'CC' => 'கோகோஸ் (கீலிங்) தீவுகள்',
        'CD' => 'காங்கோ - கின்ஷாசா',
        'CF' => 'மத்திய ஆப்ரிக்கக் குடியரசு',
        'CG' => 'காங்கோ - ப்ராஸாவில்லே',
        'CH' => 'ஸ்விட்சர்லாந்து',
        'CI' => 'கோட் தி’வாயர்',
        'CK' => 'குக் தீவுகள்',
        'CL' => 'சிலி',
        'CM' => 'கேமரூன்',
        'CN' => 'சீனா',
        'CO' => 'கொலம்பியா',
        'CR' => 'கோஸ்டாரிகா',
        'CU' => 'கியூபா',
        'CV' => 'கேப் வெர்டே',
        'CW' => 'குராகவ்',
        'CX' => 'கிறிஸ்துமஸ் தீவு',
        'CY' => 'சைப்ரஸ்',
        'CZ' => 'செசியா',
        'DE' => 'ஜெர்மனி',
        'DJ' => 'ஜிபௌட்டி',
        'DK' => 'டென்மார்க்',
        'DM' => 'டொமினிகா',
        'DO' => 'டொமினிகன் குடியரசு',
        'DZ' => 'அல்ஜீரியா',
        'EC' => 'ஈக்வடார்',
        'EE' => 'எஸ்டோனியா',
        'EG' => 'எகிப்து',
        'EH' => 'மேற்கு சஹாரா',
        'ER' => 'எரிட்ரியா',
        'ES' => 'ஸ்பெயின்',
        'ET' => 'எத்தியோப்பியா',
        'FI' => 'பின்லாந்து',
        'FJ' => 'ஃபிஜி',
        'FK' => 'ஃபாக்லாந்து தீவுகள்',
        'FM' => 'மைக்ரோனேஷியா',
        'FO' => 'ஃபாரோ தீவுகள்',
        'FR' => 'பிரான்ஸ்',
        'GA' => 'கேபான்',
        'GB' => 'யுனைடெட் கிங்டம்',
        'GD' => 'கிரனெடா',
        'GE' => 'ஜார்ஜியா',
        'GF' => 'பிரெஞ்சு கயானா',
        'GG' => 'கெர்ன்சி',
        'GH' => 'கானா',
        'GI' => 'ஜிப்ரால்டர்',
        'GL' => 'கிரீன்லாந்து',
        'GM' => 'காம்பியா',
        'GN' => 'கினியா',
        'GP' => 'க்வாதேலோப்',
        'GQ' => 'ஈக்வடோரியல் கினியா',
        'GR' => 'கிரீஸ்',
        'GS' => 'தெற்கு ஜார்ஜியா மற்றும் தெற்கு சாண்ட்விச் தீவுகள்',
        'GT' => 'கவுதமாலா',
        'GU' => 'குவாம்',
        'GW' => 'கினியா-பிஸ்ஸாவ்',
        'GY' => 'கயானா',
        'HK' => 'ஹாங்காங் எஸ்ஏஆர் சீனா',
        'HM' => 'ஹேர்ட் மற்றும் மெக்டொனால்டு தீவுகள்',
        'HN' => 'ஹோண்டூராஸ்',
        'HR' => 'குரோஷியா',
        'HT' => 'ஹைட்டி',
        'HU' => 'ஹங்கேரி',
        'ID' => 'இந்தோனேசியா',
        'IE' => 'அயர்லாந்து',
        'IL' => 'இஸ்ரேல்',
        'IM' => 'ஐல் ஆஃப் மேன்',
        'IN' => 'இந்தியா',
        'IO' => 'பிரிட்டிஷ் இந்தியப் பெருங்கடல் பிரதேசம்',
        'IQ' => 'ஈராக்',
        'IR' => 'ஈரான்',
        'IS' => 'ஐஸ்லாந்து',
        'IT' => 'இத்தாலி',
        'JE' => 'ஜெர்சி',
        'JM' => 'ஜமைகா',
        'JO' => 'ஜோர்டான்',
        'JP' => 'ஜப்பான்',
        'KE' => 'கென்யா',
        'KG' => 'கிர்கிஸ்தான்',
        'KH' => 'கம்போடியா',
        'KI' => 'கிரிபாட்டி',
        'KM' => 'கோமரோஸ்',
        'KN' => 'செயின்ட் கிட்ஸ் & நெவிஸ்',
        'KP' => 'வட கொரியா',
        'KR' => 'தென் கொரியா',
        'KW' => 'குவைத்',
        'KY' => 'கெய்மென் தீவுகள்',
        'KZ' => 'கஸகஸ்தான்',
        'LA' => 'லாவோஸ்',
        'LB' => 'லெபனான்',
        'LC' => 'செயின்ட் லூசியா',
        'LI' => 'லிச்செண்ஸ்டெய்ன்',
        'LK' => 'இலங்கை',
        'LR' => 'லைபீரியா',
        'LS' => 'லெசோதோ',
        'LT' => 'லிதுவேனியா',
        'LU' => 'லக்ஸ்சம்பர்க்',
        'LV' => 'லாட்வியா',
        'LY' => 'லிபியா',
        'MA' => 'மொராக்கோ',
        'MC' => 'மொனாக்கோ',
        'MD' => 'மால்டோவா',
        'ME' => 'மான்டேனெக்ரோ',
        'MF' => 'செயின்ட் மார்ட்டீன்',
        'MG' => 'மடகாஸ்கர்',
        'MH' => 'மார்ஷல் தீவுகள்',
        'MK' => 'வடக்கு மாசிடோனியா',
        'ML' => 'மாலி',
        'MM' => 'மியான்மார் (பர்மா)',
        'MN' => 'மங்கோலியா',
        'MO' => 'மகாவ் எஸ்ஏஆர் சீனா',
        'MP' => 'வடக்கு மரியானா தீவுகள்',
        'MQ' => 'மார்டினிக்',
        'MR' => 'மௌரிடானியா',
        'MS' => 'மாண்ட்செராட்',
        'MT' => 'மால்டா',
        'MU' => 'மொரிசியஸ்',
        'MV' => 'மாலத்தீவு',
        'MW' => 'மலாவி',
        'MX' => 'மெக்சிகோ',
        'MY' => 'மலேசியா',
        'MZ' => 'மொசாம்பிக்',
        'NA' => 'நமீபியா',
        'NC' => 'நியூ கேலிடோனியா',
        'NE' => 'நைஜர்',
        'NF' => 'நார்ஃபோக் தீவு',
        'NG' => 'நைஜீரியா',
        'NI' => 'நிகரகுவா',
        'NL' => 'நெதர்லாந்து',
        'NO' => 'நார்வே',
        'NP' => 'நேபாளம்',
        'NR' => 'நௌரு',
        'NU' => 'நியுவே',
        'NZ' => 'நியூசிலாந்து',
        'OM' => 'ஓமன்',
        'PA' => 'பனாமா',
        'PE' => 'பெரு',
        'PF' => 'பிரெஞ்சு பாலினேஷியா',
        'PG' => 'பப்புவா நியூ கினியா',
        'PH' => 'பிலிப்பைன்ஸ்',
        'PK' => 'பாகிஸ்தான்',
        'PL' => 'போலந்து',
        'PM' => 'செயின்ட் பியர் & மிக்வேலான்',
        'PN' => 'பிட்கெய்ர்ன் தீவுகள்',
        'PR' => 'பியூர்டோ ரிகோ',
        'PS' => 'பாலஸ்தீனிய பிரதேசங்கள்',
        'PT' => 'போர்ச்சுக்கல்',
        'PW' => 'பாலோ',
        'PY' => 'பராகுவே',
        'QA' => 'கத்தார்',
        'RE' => 'ரீயூனியன்',
        'RO' => 'ருமேனியா',
        'RS' => 'செர்பியா',
        'RU' => 'ரஷ்யா',
        'RW' => 'ருவாண்டா',
        'SA' => 'சவூதி அரேபியா',
        'SB' => 'சாலமன் தீவுகள்',
        'SC' => 'சீஷெல்ஸ்',
        'SD' => 'சூடான்',
        'SE' => 'ஸ்வீடன்',
        'SG' => 'சிங்கப்பூர்',
        'SH' => 'செயின்ட் ஹெலெனா',
        'SI' => 'ஸ்லோவேனியா',
        'SJ' => 'ஸ்வல்பார்டு & ஜான் மேயன்',
        'SK' => 'ஸ்லோவாகியா',
        'SL' => 'சியாரா லியோன்',
        'SM' => 'சான் மரினோ',
        'SN' => 'செனெகல்',
        'SO' => 'சோமாலியா',
        'SR' => 'சுரினாம்',
        'SS' => 'தெற்கு சூடான்',
        'ST' => 'சாவ் தோம் & ப்ரின்சிபி',
        'SV' => 'எல் சால்வடார்',
        'SX' => 'சின்ட் மார்டென்',
        'SY' => 'சிரியா',
        'SZ' => 'எஸ்வாட்டீனி',
        'TC' => 'டர்க்ஸ் & கைகோஸ் தீவுகள்',
        'TD' => 'சாட்',
        'TF' => 'பிரெஞ்சு தெற்கு பிரதேசங்கள்',
        'TG' => 'டோகோ',
        'TH' => 'தாய்லாந்து',
        'TJ' => 'தஜிகிஸ்தான்',
        'TK' => 'டோகேலோ',
        'TL' => 'திமோர்-லெஸ்தே',
        'TM' => 'துர்க்மெனிஸ்தான்',
        'TN' => 'டுனிசியா',
        'TO' => 'டோங்கா',
        'TR' => 'துருக்கி',
        'TT' => 'டிரினிடாட் & டொபாகோ',
        'TV' => 'துவாலு',
        'TW' => 'தைவான்',
        'TZ' => 'தான்சானியா',
        'UA' => 'உக்ரைன்',
        'UG' => 'உகாண்டா',
        'UM' => 'யூ.எஸ். வெளிப்புறத் தீவுகள்',
        'US' => 'அமெரிக்கா',
        'UY' => 'உருகுவே',
        'UZ' => 'உஸ்பெகிஸ்தான்',
        'VA' => 'வாடிகன் நகரம்',
        'VC' => 'செயின்ட் வின்சென்ட் & கிரெனடைன்ஸ்',
        'VE' => 'வெனிசுலா',
        'VG' => 'பிரிட்டீஷ் கன்னித் தீவுகள்',
        'VI' => 'யூ.எஸ். கன்னித் தீவுகள்',
        'VN' => 'வியட்நாம்',
        'VU' => 'வனுவாட்டு',
        'WF' => 'வாலிஸ் மற்றும் ஃபுடுனா',
        'WS' => 'சமோவா',
        'YE' => 'ஏமன்',
        'YT' => 'மயோட்',
        'ZA' => 'தென் ஆப்பிரிக்கா',
        'ZM' => 'ஜாம்பியா',
        'ZW' => 'ஜிம்பாப்வே',
    ],
];

==> symfony_7.3.4+dfsg.orig.tar.xz: symfony-7.3.4/src/Symfony/Component/Intl/Resources/data/regions/ta.php <==
<?php

return [
    'UserAssignedNames' => [
        'XK' => 'கொசோவோ',
    ],
    'Names' => [
        'AD' => 'அன்டோரா',
        'AE' => 'ஐக்கிய அரபு எமிரேட்ஸ்',
        'AF' => 'ஆஃப்கானிஸ்தான்',
        'AG' => 'ஆண்டிகுவா மற்றும் பார்புடா',
        'AI' => 'அங்கியுலா',
        'AL' => 'அல்பேனியா',
        'AM' => 'அர்மேனியா',
        'AO' => 'அங்கோலா',
        'AQ' => 'அண்டார்டிகா',
        'AR' => 'அர்ஜென்டினா',
        'AS' => 'அமெரிக்க சமோவா',
        'AT' => 'ஆஸ்திரியா',
        'AU' => 'ஆஸ்திரேலியா',
        'AW' => 'அரூபா',
        'AX' => 'ஆலந்து தீவுகள்',
        'AZ' => 'அசர்பைஜான்',
        'BA' => 'போஸ்னியா & ஹெர்ஸகோவினா',
        'BB' => 'பார்படாஸ்',
        'BD' => 'பங்களாதேஷ்',
        'BE' => 'பெல்ஜியம்',
        'BF' => 'புர்கினா ஃபாஸோ',
        'BG' => 'பல்கேரியா',
        'BH' => 'பஹ்ரைன்',
        'BI' => 'புருண்டி',
        'BJ' => 'பெனின்',
        'BL' => 'செயின்ட் பார்தேலெமி',
        'BM' => 'பெர்முடா',
        'BN' => 'புருனே',
        'BO' => 'பொலிவியா',
        'BQ' => 'கரீபியன் நெதர்லாந்து',
        'BR' => 'பிரேசில்',
        'BS' => 'பஹாமாஸ்',
        'BT' => 'பூடான்',
        'BV' => 'பொவேட் தீவு',
        'BW' => 'போட்ஸ்வானா',
        'BY' => 'பெலாரஸ்',
        'BZ' => 'பெலிஸ்',
        'CA' => 'கனடா',
        'CC' => 'கோகோஸ் (கீலிங்) தீவுகள்',
        'CD' => 'காங்கோ - கின்ஷாசா',
        'CF' => 'மத்திய ஆப்ரிக்கக் குடியரசு',
        'CG' => 'காங்கோ - ப்ராஸாவில்லே',
        'CH' => 'ஸ்விட்சர்லாந்து',
        'CI' => 'கோட் தி’வாயர்',
        'CK' => 'குக் தீவுகள்',
        'CL' => 'சிலி',
        'CM' => 'கேமரூன்',
        'CN' => 'சீனா',
        'CO' => 'கொலம்பியா',
        'CR' => 'கோஸ்டாரிகா',
        'CU' => 'கியூபா',
        'CV' => 'கேப் வெர்டே',
        'CW' => 'குராகவ்',
        'CX' => 'கிறிஸ்துமஸ் தீவு',
        'CY' => 'சைப்ரஸ்',
        'CZ' => 'செசியா',
        'DE' => 'ஜெர்மனி',
        'DJ' => 'ஜிபௌட்டி',
        'DK' => 'டென்மார்க்',
        'DM' => 'டொமினிகா',
        'DO' => 'டொமினிகன் குடியரசு',
        'DZ' => 'அல்ஜீரியா',
        'EC' => 'ஈக்வடார்',
        'EE' => 'எஸ்டோனியா',
        'EG' => 'எகிப்து',
        'EH' => 'மேற்கு சஹாரா',
        'ER' => 'எரிட்ரியா',
        'ES' => 'ஸ்பெயின்',
        'ET' => 'எத்தியோப்பியா',
        'FI' => 'பின்லாந்து',
        'FJ' => 'ஃபிஜி',
        'FK' => 'ஃபாக்லாந்து தீவுகள்',
        'FM' => 'மைக்ரோனேஷியா',
        'FO' => 'ஃபாரோ தீவுகள்',
        'FR' => 'பிரான்ஸ்',
        'GA' => 'கேபான்',
        'GB' => 'யுனைடெட் கிங்டம்',
        'GD' => 'கிரனெடா',
        'GE' => 'ஜார்ஜியா',
        'GF' => 'பிரெஞ்சு கயானா',
        'GG' => 'கெர்ன்சி',
        'GH' => 'கானா',
        'GI' => 'ஜிப்ரால்டர்',
        'GL' => 'கிரீன்லாந்து',
        'GM' => 'காம்பியா',
        'GN' => 'கினியா',
        'GP' => 'க்வாதேலோப்',
        'GQ' => 'ஈக்வடோரியல் கினியா',
        'GR' => 'கிரீஸ்',
        'GS' => 'தெற்கு ஜார்ஜியா மற்றும் தெற்கு சாண்ட்விச் தீவுகள்',
        'GT' => 'கவுதமாலா',
        'GU' => 'குவாம்',
        'GW' => 'கினியா-பிஸ்ஸாவ்',
        'GY' => 'கயானா',
        'HK' => 'ஹாங்காங் எஸ்ஏஆர் சீனா',
        'HM' => 'ஹேர்ட் மற்றும் மெக்டொனால்டு தீவுகள்',
        'HN' => 'ஹோண்டூராஸ்',
        'HR' => 'குரோஷியா',
        'HT' => 'ஹைட்டி',
        'HU' => 'ஹங்கேரி',
        'ID' => 'இந்தோனேசியா',
        'IE' => 'அயர்லாந்து',
        'IL' => 'இஸ்ரேல்',
        'IM' => 'ஐல் ஆஃப் மேன்',
        'IN' => 'இந்தியா',
        'IO' => 'பிரிட்டிஷ் இந்தியப் பெருங்கடல் பிரதேசம்',
        'IQ' => 'ஈராக்',
        'IR' => 'ஈரான்',
        'IS' => 'ஐஸ்லாந்து',
        'IT' => 'இத்தாலி',
        'JE' => 'ஜெர்சி',
        'JM' => 'ஜமைகா',
        'JO' => 'ஜோர்டான்',
        'JP' => 'ஜப்பான்',
        'KE' => 'கென்யா',
        'KG' => 'கிர்கிஸ்தான்',
        'KH' => 'கம்போடியா',
        'KI' => 'கிரிபாட்டி',
        'KM' => 'கோமரோஸ்',
        'KN' => 'செயின்ட் கிட்ஸ் & நெவிஸ்',
        'KP' => 'வட கொரியா',
        'KR' => 'தென் கொரியா',
        'KW' => 'குவைத்',
        'KY' => 'கெய்மென் தீவுகள்',
        'KZ' => 'கஸகஸ்தான்',
        'LA' => 'லாவோஸ்',
        'LB' => 'லெபனான்',
        'LC' => 'செயின்ட் லூசியா',
        'LI' => 'லிச்செண்ஸ்டெய்ன்',
        'LK' => 'இலங்கை',
        'LR' => 'லைபீரியா',
        'LS' => 'லெசோதோ',
        'LT' => 'லிதுவேனியா',
        'LU' => 'லக்ஸ்சம்பர்க்',
        'LV' => 'லாட்வியா',
        'LY' => 'லிபியா',
        'MA' => 'மொராக்கோ',
        'MC' => 'மொனாக்கோ',
        'MD' => 'மால்டோவா',
        'ME' => 'மான்டேனெக்ரோ',
        'MF' => 'செயின்ட் மார்ட்டீன்',
        'MG' => 'மடகாஸ்கர்',
        'MH' => 'மார்ஷல் தீவுகள்',
        'MK' => 'வடக்கு மாசிடோனியா',
        'ML' => 'மாலி',
        'MM' => 'மியான்மார் (பர்மா)',
        'MN' => 'மங்கோலியா',
        'MO' => 'மகாவ் எஸ்ஏஆர் சீனா',
        'MP' => 'வடக்கு மரியானா தீவுகள்',
        'MQ' => 'மார்டினிக்',
        'MR' => 'மௌரிடானியா',
        'MS' => 'மாண்ட்செராட்',
        'MT' => 'மால்டா',
        'MU' => 'மொரிசியஸ்',
        'MV' => 'மாலத்தீவு',
        'MW' => 'மலாவி',
        'MX' => 'மெக்சிகோ',
        'MY' => 'மலேசியா',
        'MZ' => 'மொசாம்பிக்',
        'NA' => 'நமீபியா',
        'NC' => 'நியூ கேலிடோனியா',
        'NE' => 'நைஜர்',
        'NF' => 'நார்ஃபோக் தீவு',
        'NG' => 'நைஜீரியா',
        'NI' => 'நிகரகுவா',
        'NL' => 'நெதர்லாந்து',
        'NO' => 'நார்வே',
        'NP' => 'நேபாளம்',
        'NR' => 'நௌரு',
        'NU' => 'நியுவே',
        'NZ' => 'நியூசிலாந்து',
        'OM' => 'ஓமன்',
        'PA' => 'பனாமா',
        'PE' => 'பெரு',
        'PF' => 'பிரெஞ்சு பாலினேஷியா',
        'PG' => 'பப்புவா நியூ கினியா',
        'PH' => 'பிலிப்பைன்ஸ்',
        'PK' => 'பாகிஸ்தான்',
        'PL' => 'போலந்து',
        'PM' => 'செயின்ட் பியர் & மிக்வேலான்',
        'PN' => 'பிட்கெய்ர்ன் தீவுகள்',
        'PR' => 'பியூர்டோ ரிகோ',
        'PS' => 'பாலஸ்தீனிய பிரதேசங்கள்',
        'PT' => 'போர்ச்சுக்கல்',
        'PW' => 'பாலோ',
        'PY' => 'பராகுவே',
        'QA' => 'கத்தார்',
        'RE' => 'ரீயூனியன்',
        'RO' => 'ருமேனியா',
        'RS' => 'செர்பியா',
        'RU' => 'ரஷ்யா',
        'RW' => 'ருவாண்டா',
        'SA' => 'சவுதி அரேபியா',
        'SB' => 'சாலமன் தீவுகள்',
        'SC' => 'சீஷெல்ஸ்',
        'SD' => 'சூடான்',
        'SE' => 'ஸ்வீடன்',
        'SG' => 'சிங்கப்பூர்',
        'SH' => 'செயின்ட் ஹெலெனா',
        'SI' => 'ஸ்லோவேனியா',
        'SJ' => 'ஸ்வல்பார்டு & ஜான் மேயன்',
        'SK' => 'ஸ்லோவாகியா',
        'SL' => 'சியாரா லியோன்',
        'SM' => 'சான் மரினோ',
        'SN' => 'செனெகல்',
        'SO' => 'சோமாலியா',
        'SR' => 'சுரினாம்',
        'SS' => 'தெற்கு சூடான்',
        'ST' => 'சாவ் தோம் & ப்ரின்சிபி',
        'SV' => 'எல் சால்வடார்',
        'SX' => 'சின்ட் மார்டென்',
        'SY' => 'சிரியா',
        'SZ' => 'எஸ்வாட்டீனி',
        'TC' => 'டர்க்ஸ் & கைகோஸ் தீவுகள்',
        'TD' => 'சாட்',
        'TF' => 'பிரெஞ்சு தெற்கு பிரதேசங்கள்',
        'TG' => 'டோகோ',
        'TH' => 'தாய்லாந்து',
        'TJ' => 'தஜிகிஸ்தான்',
        'TK' => 'டோகேலோ',
        'TL' => 'திமோர்-லெஸ்தே',
        'TM' => 'துர்க்மெனிஸ்தான்',
        'TN' => 'டுனிசியா',
        'TO' => 'டோங்கா',
        'TR' => 'துருக்கியே',
        'TT' => 'டிரினிடாட் & டொபாகோ',
        'TV' => 'துவாலு',
        'TW' => 'தைவான்',
        'TZ' => 'தான்சானியா',
        'UA' => 'உக்ரைன்',
        'UG' => 'உகாண்டா',
        'UM' => 'யூ.எஸ். வெளிப்புறத் தீவுகள்',
        'US' => 'அமெரிக்கா',
        'UY' => 'உருகுவே',
        'UZ' => 'உஸ்பெகிஸ்தான்',
        'VA' => 'வாடிகன் நகரம்',
        'VC' => 'செயின்ட் வின்சென்ட் & கிரெனடைன்ஸ்',
        'VE' => 'வெனிசுலா',
        'VG' => 'பிரிட்டீஷ் கன்னித் தீவுகள்',
        'VI' => 'யூ.எஸ். கன்னித் தீவுகள்',
        'VN' => 'வியட்நாம்',
        'VU' => 'வனுவாட்டு',
        'WF' => 'வாலிஸ் மற்றும் ஃபுடுனா',
        'WS' => 'சமோவா',
        'YE' => 'ஏமன்',
        'YT' => 'மயோட்',
        'ZA' => 'தென் ஆப்பிரிக்கா',
        'ZM' => 'ஜாம்பியா',
        'ZW' => 'ஜிம்பாப்வே',
    ],
];
